@@ -65,6 +65,7 @@ class SupeRSS:
     # required arg
     self.feed = feed
     self.homepage = homepage
+    self.ignore_urls = kwargs.get('ignore_urls', set())
 
     # if we haven't import particle, assume we have the full text
     if imported_particle:
@@ -204,7 +205,7 @@ class SupeRSS:
     Parse an entry. if not full text, extract the article
     by opening the page and merge the results.
     """
-    article_html = self.get_article_html( entry )
+    article_html = self.get_article_html(entry)
 
     data = {
       'url':           self.get_url(entry),
@@ -241,7 +242,6 @@ class SupeRSS:
 
     return d 
 
-
   def run_homepage(self):
     pg1 = PageOne(url=self.homepage)
     p = Particle()
@@ -265,10 +265,9 @@ class SupeRSS:
     # we check for duplicates we get them first.
     entries = reversed(f.entries)
     for entry in f.entries:
-      data = self.parse_entry(entry)
-      yield data 
+      yield self.parse_entry(entry)
 
-  def run(self):
+  def _run(self):
     """
     run different methods based on intialization parameters
     """
@@ -283,4 +282,9 @@ class SupeRSS:
       else:
         return self.run_non_full_text()
 
+  def run(self):
+    for entry in self._run():
+      if entry and entry['url'] not in self.ignore_urls:
+        yield entry
+
 
